block_server_thread_release

Function block_server_thread_release 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn block_server_thread_release( arg: *const c_void, )
Called to release the thread. This must always be called on the thread spawned by Callbacks::start_thread, regardless of whether block_server_thread is called or not.

Safety

arg must be the value passed to the start_thread callback.