pub struct Request {
pub request_id: RequestId,
pub operation: Operation,
pub trace_flow_id: Option<NonZero<u64>>,
pub vmo: Option<Arc<Vmo>>,
}Expand description
An in-flight request.
Fields
request_id: RequestIdThe ID that a request is associated with, for later completion in
SessionManager::complete_request. Note that this is not necessarily a unique
identifier, and multiple Requests may have the same request_id (e.g. due to request
splitting). The library internally reference-counts requests which use this ID.
operation: Operationtrace_flow_id: Option<NonZero<u64>>vmo: Option<Arc<Vmo>>vmo is always Some for Operation::Read or Operation::Write, and None otherwise.