pub enum DeviceInfo {
Block(BlockInfo),
Partition(PartitionInfo),
Volume(VolumeInfo),
}Variants
Block(BlockInfo)
A raw non-partition block device.
Partition(PartitionInfo)
A static partition with fixed physical mappings.
Volume(VolumeInfo)
A dynamic volume whose slice/block count is queried via get_volume_info.
Implementations
Sourceimpl DeviceInfo
impl DeviceInfo
pub fn label(&self) -> &str
pub fn device_flags(&self) -> DeviceFlag
Sourcepub fn block_count(&self) -> Option<u64>
pub fn block_count(&self) -> Option<u64>
Returns the block count of the device or partition. Returns None for dynamic volumes (whose size needs to be queried from the volume manager).
pub fn max_transfer_blocks(&self) -> Option<NonZero<u32>>
pub fn type_guid(&self) -> Option<[u8; 16]>
pub fn instance_guid(&self) -> Option<[u8; 16]>