coalesce_mappings

Function coalesce_mappings 

pub fn coalesce_mappings(
    raw_mappings: Vec<BlockOffsetMapping>,
) -> Vec<BlockOffsetMapping>
Merges physically contiguous mappings into single logical mappings. This is useful because it prevents requests from being unnecessarily split if they span the two mappings.