pub struct PartitionInfo {
pub device_flags: DeviceFlag,
pub max_transfer_blocks: Option<NonZero<u32>>,
pub start_block_offset: Option<u64>,
pub block_count: u64,
pub type_guid: [u8; 16],
pub instance_guid: [u8; 16],
pub name: String,
pub flags: Option<u64>,
}Expand description
Information associated with a block device that is also a partition.
Fields
device_flags: DeviceFlagThe device flags reported by the underlying device.
max_transfer_blocks: Option<NonZero<u32>>start_block_offset: Option<u64>This is None for partitions which have multiple logical extents, in which case the start_block_offset is not meaningful and potentially confusing.
block_count: u64type_guid: [u8; 16]instance_guid: [u8; 16]name: Stringflags: Option<u64>This can be None for partitions which are composed of multiple partitions (e.g. an overlay partition in GPT).