pub fn coalesce_mappings(
raw_mappings: Vec<BlockOffsetMapping>,
) -> Vec<BlockOffsetMapping>Expand description
Merges physically contiguous mappings into single logical mappings. This is useful because it prevents requests from being unnecessarily split if they span the two mappings.